@@ -1,4 +1,4 @@
-from importlib_resources import path
+from importlib.resources import path
 import os
 import logging
 
@@ -63,6 +63,8 @@ class Config:
         self.withscores = False
         self.version = "Unknown"
 
+        self.greetings = True
+
         self.prompt = None
 
     def __setter__(self, name, value):
@@ -86,13 +88,13 @@ def read_config_file(f):
         config = ConfigObj(f, interpolation=False, encoding="utf8")
     except ConfigObjError as e:
         logger.error(
-            "Unable to parse line {0} of config file " "'{1}'.".format(e.line_number, f)
+            "Unable to parse line {} of config file " "'{}'.".format(e.line_number, f)
         )
         logger.error("Using successfully parsed config values.")
         return e.config
-    except (IOError, OSError) as e:
+    except OSError as e:
         logger.error(
-            "You don't have permission to read " "config file '{0}'.".format(e.filename)
+            "You don't have permission to read " "config file '{}'.".format(e.filename)
         )
         return None
 
@@ -129,5 +131,6 @@ def load_config_files(iredisrc):
     config.pager = config_obj["main"].get("pager")
     config.enable_pager = config_obj["main"].as_bool("enable_pager")
     config.prompt = config_obj["main"].get("prompt")
+    config.greetings = config_obj["main"].as_bool("greetings")
 
     return config_obj
